@@ -1,4 +1,4 @@
-from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime, JSON
+from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime, JSON, ARRAY
 from sqlalchemy.orm import relationship, validates
 from sqlalchemy.sql import func
 
@@ -1137,19 +1137,209 @@ class OverrideStudent(Base):
 
 class User(Base):
     """
-    Модель "Пользователь"
+    Пользователь
     """
-
     __tablename__ = 'users'
 
+    # Идентификатор
     id = Column(Integer, primary_key=True)
+
+    # Полное имя (ФИО)
     name = Column(String(255))
 
+    # Полное имя для сортировки
+    sortable_name = Column(String(255))
+
+    # Короткое имя
+    short_name = Column(String(255))
+
+    # Статус
+    # Возможные значения:
+    # - pre_registered (???)
+    # - registered (Зарегистрирован)
+    # - creation_pending (???)
+    # - deleted (Удален)
+    workflow_state = Column(String(255), default='registered')
+
+    @validates('workflow_state')
+    def validate_workflow_state(self, key, value):
+        """
+        Значением workflow_state может быть следующие значения:
+        - pre_registered (???)
+        - registered (Зарегистрирован)
+        - creation_pending (???)
+        - deleted (Удален)
+        """
+        assert value in ['pre_registered',
+                         'registered', 'creation_pending', 'deleted']
+        return value
+
+    # Временная зона
+    # Необходимо написать на английском
+    # Пример: Almaty, Astana, Baku, Berlin, Ekaterinburg, Islamabad, Moscow и т.д.
+    time_zone = Column(String(255))
+
+    # Уникальные UUID-идентификатор
+    uuid = Column(String(255))
+
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # URL-адрес изображения к аватару (Фото пользователя)
+    avatar_image_url = Column(String(255))
+
+    # Источник аватара (Фото пользователя)
+    # Возможные значения:
+    # - attachment
+    # - gravatar
+    # - no_pic
+    avatar_image_source = Column(String(255))
+
+    @validates('avatar_image_source')
+    def validate_avatar_image_source(self, key, value):
+        if value:
+            assert value in ['attachment', 'gravatar', 'no_pic']
+
+        return value
+
+    # Дата и время изменения аватара (Фото пользователя)
+    # Если аватар изменился, нужно поменять дату и время
+    avatar_image_updated_at = Column(DateTime)
+
+    # Номер телефона
+    phone = Column(String(255))
+
+    # Наименование школы
+    school_name = Column(String(255))
+
+    # Позиция школы (???)
+    school_position = Column(String(255))
+
+    # Дата и время удаления
+    # Обязателен, если workflow_state="deleted"
+    deleted_at = Column(DateTime)
+
+    @validates('deleted_at')
+    def validate_deleted_at(self, key, value):
+        if self.workflow_state == 'deleted':
+            assert value is not None
+
+        return value
+
+    # Неизвестное поле
+    show_user_services = Column(Boolean)
+
+    # Неизвестное поле
+    page_views_count = Column(Boolean)
+
+    # Неизвестное поле
+    reminder_time_for_due_dates = Column(Integer)
+
+    # Неизвестное поле
+    reminder_time_for_grading = Column(Integer)
+
+    # Неизвестное поле (Возможно квота на хранилище файлов)
+    storage_quota = Column(Integer)
+
+    # Неизвестное поле
+    visible_inbox_types = Column(String(255))
+
+    # Неизвестное поле
+    last_user_note = Column(DateTime)
+
+    # Неизвестное поле (Возможно, подписывать на email)
+    subscribe_to_emails = Column(Boolean)
+
+    # Неизвестное поле
+    features_used = Column(String)
+
+    # Настройки
+    # В формате YAML
+    preferences = Column(String)
+
+    # Неизвестное поле (Возможно статус аватара - фото пользователя)
+    # Возможные значения:
+    # - approved
+    # - none
+    # - reported
+    # - submitted
+    avatar_state = Column(String(255))
+
+    @validates('avatar_state')
+    def validate_avatar_state(self, key, value):
+        """
+        Значением avatar_state может быть следующие значения:
+        - approved
+        - none
+        - reported
+        - submitted
+        """
+        if value:
+            assert value in ['approved', 'none', 'reported', 'submitted']
+
+        return value
+
+    # Выбранный язык интерфейса
+    # Пример: en, en-GB, ru и т.д.
+    locale = Column(String(255))
+
+    # Неизвестное поле
+    browser_locale = Column(String(255))
+
+    # Количество непрочитанных сообщении во входящем
+    unread_conversations_count = Column(Integer)
+
+    # Неизвестное поле (Возможно означает какие данные не будут менятся при импорте через SIS-импорт)
+    # Вводятся поля через запятую
+    # Пример: name,sortable_name и т.д.
+    stuck_sis_fields = Column(String)
+
+    # Неизвестное поле
+    public = Column(Boolean)
+
+    # Неизвестное поле (Возможно относится к двухфакторному аутентификацию)
+    otp_secret_key_enc = Column(String(255))
+
+    # Неизвестное поле (Возможно относится к двухфакторному аутентификацию)
+    otp_secret_key_salt = Column(String(255))
+
+    # Неизвестное поле (Возможно относится к двухфакторному аутентификацию)
+    otp_communication_channel_id = Column(Integer)
+
+    # Неизвестное поле
+    initial_enrollment_type = Column(String(255))
+
+    # Неизвестное поле (Относится к сервису Crocodoc)
+    crocodoc_id = Column(Integer)
+
+    # Дата и время последнего выхода из системы
+    last_logged_out = Column(DateTime)
+
+    # Контекстный LTI-идентификатор
+    lti_context_id = Column(String(255))
+
+    # Идентификатор TurnItIn
+    turnitin_id = Column(Integer)
+
+    # LTI-идентификатор пользователя
+    lti_id = Column(String(255))
+
+    # Неизвестное поле
+    pronouns = Column(String)
+
+    # Неизвестное поле (Массив целых чисел)
+    root_account_ids = Column(ARRAY(Integer))
+
     def __repr__(self):
-        return '<User {} (id={})>'.format(self, self.id)
+        return f'<User {self} (id={self.id} workflow_state={self.workflow_state})>'
 
     def __str__(self):
-        return self.name
+        return f'{self.name}'
 
 
 class Pseudonym(Base):
@@ -1219,7 +1409,7 @@ class Enrollment(Base):
     # Статус
     # active - Активный
     # deleted - Удаленный
-    workflow_state = Column(String(255))
+    workflow_state = Column(String(255), default='active')
 
     # Дата и время создания
     created_at = Column(DateTime)
